@@ -1,14 +1,14 @@
 """
 Type annotations for devops-guru service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_devops_guru.literals import AnomalySeverity
+    from mypy_boto3_devops_guru.literals import AnomalySeverityType
 
-    data: AnomalySeverity = "HIGH"
+    data: AnomalySeverityType = "HIGH"
     ```
 """
 import sys
@@ -20,64 +20,64 @@ else:
 
 
 __all__ = (
-    "AnomalySeverity",
-    "AnomalyStatus",
-    "CloudWatchMetricsStat",
-    "CostEstimationServiceResourceState",
-    "CostEstimationStatus",
+    "AnomalySeverityType",
+    "AnomalyStatusType",
+    "CloudWatchMetricsStatType",
+    "CostEstimationServiceResourceStateType",
+    "CostEstimationStatusType",
     "DescribeResourceCollectionHealthPaginatorName",
-    "EventClass",
-    "EventDataSource",
+    "EventClassType",
+    "EventDataSourceType",
     "GetCostEstimationPaginatorName",
     "GetResourceCollectionPaginatorName",
-    "InsightFeedbackOption",
-    "InsightSeverity",
-    "InsightStatus",
-    "InsightType",
+    "InsightFeedbackOptionType",
+    "InsightSeverityType",
+    "InsightStatusType",
+    "InsightTypeType",
     "ListAnomaliesForInsightPaginatorName",
     "ListEventsPaginatorName",
     "ListInsightsPaginatorName",
     "ListNotificationChannelsPaginatorName",
     "ListRecommendationsPaginatorName",
-    "Locale",
-    "OptInStatus",
-    "ResourceCollectionType",
+    "LocaleType",
+    "OptInStatusType",
+    "ResourceCollectionTypeType",
     "SearchInsightsPaginatorName",
-    "ServiceName",
-    "UpdateResourceCollectionAction",
+    "ServiceNameType",
+    "UpdateResourceCollectionActionType",
 )
 
 
-AnomalySeverity = Literal["HIGH", "LOW", "MEDIUM"]
-AnomalyStatus = Literal["CLOSED", "ONGOING"]
-CloudWatchMetricsStat = Literal[
+AnomalySeverityType = Literal["HIGH", "LOW", "MEDIUM"]
+AnomalyStatusType = Literal["CLOSED", "ONGOING"]
+CloudWatchMetricsStatType = Literal[
     "Average", "Maximum", "Minimum", "SampleCount", "Sum", "p50", "p90", "p99"
 ]
-CostEstimationServiceResourceState = Literal["ACTIVE", "INACTIVE"]
-CostEstimationStatus = Literal["COMPLETED", "ONGOING"]
+CostEstimationServiceResourceStateType = Literal["ACTIVE", "INACTIVE"]
+CostEstimationStatusType = Literal["COMPLETED", "ONGOING"]
 DescribeResourceCollectionHealthPaginatorName = Literal["describe_resource_collection_health"]
-EventClass = Literal[
+EventClassType = Literal[
     "CONFIG_CHANGE", "DEPLOYMENT", "INFRASTRUCTURE", "SCHEMA_CHANGE", "SECURITY_CHANGE"
 ]
-EventDataSource = Literal["AWS_CLOUD_TRAIL", "AWS_CODE_DEPLOY"]
+EventDataSourceType = Literal["AWS_CLOUD_TRAIL", "AWS_CODE_DEPLOY"]
 GetCostEstimationPaginatorName = Literal["get_cost_estimation"]
 GetResourceCollectionPaginatorName = Literal["get_resource_collection"]
-InsightFeedbackOption = Literal[
+InsightFeedbackOptionType = Literal[
     "ALERT_TOO_SENSITIVE",
     "DATA_INCORRECT",
     "DATA_NOISY_ANOMALY",
     "RECOMMENDATION_USEFUL",
     "VALID_COLLECTION",
 ]
-InsightSeverity = Literal["HIGH", "LOW", "MEDIUM"]
-InsightStatus = Literal["CLOSED", "ONGOING"]
-InsightType = Literal["PROACTIVE", "REACTIVE"]
+InsightSeverityType = Literal["HIGH", "LOW", "MEDIUM"]
+InsightStatusType = Literal["CLOSED", "ONGOING"]
+InsightTypeType = Literal["PROACTIVE", "REACTIVE"]
 ListAnomaliesForInsightPaginatorName = Literal["list_anomalies_for_insight"]
 ListEventsPaginatorName = Literal["list_events"]
 ListInsightsPaginatorName = Literal["list_insights"]
 ListNotificationChannelsPaginatorName = Literal["list_notification_channels"]
 ListRecommendationsPaginatorName = Literal["list_recommendations"]
-Locale = Literal[
+LocaleType = Literal[
     "DE_DE",
     "EN_GB",
     "EN_US",
@@ -90,10 +90,10 @@ Locale = Literal[
     "ZH_CN",
     "ZH_TW",
 ]
-OptInStatus = Literal["DISABLED", "ENABLED"]
-ResourceCollectionType = Literal["AWS_CLOUD_FORMATION", "AWS_SERVICE"]
+OptInStatusType = Literal["DISABLED", "ENABLED"]
+ResourceCollectionTypeType = Literal["AWS_CLOUD_FORMATION", "AWS_SERVICE"]
 SearchInsightsPaginatorName = Literal["search_insights"]
-ServiceName = Literal[
+ServiceNameType = Literal[
     "API_GATEWAY",
     "APPLICATION_ELB",
     "AUTO_SCALING_GROUP",
@@ -120,4 +120,4 @@ ServiceName = Literal[
     "STEP_FUNCTIONS",
     "SWF",
 ]
-UpdateResourceCollectionAction = Literal["ADD", "REMOVE"]
+UpdateResourceCollectionActionType = Literal["ADD", "REMOVE"]
